@@ -1,4 +1,4 @@
 NCAselect.BANOVA<-function(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis){
 NCAselect(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata, xaxis, yaxis,
-          Demo=FALSE, BANOVA=TRUE)
+          Demo=TRUE, BANOVA=TRUE)  ### switch 'Demo=TRUE' for testing
 }
\ No newline at end of file
