@@ -1,5 +1,4 @@
-
 TTTAICdemo<-function(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1){
 TTTAIC(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1,
-    Demo=TRUE, BANOVA=FALSE)
+    Demo=TRUE, BANOVA=FALSE,replicated=FALSE)
 }
\ No newline at end of file
